<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'session_check.php';
require_once 'config.php';
require_once 'classes/ConfigManager.php';

$configManager = new ConfigManager($pdo);
$message = '';
$messageType = '';

function isPNG($file) {
    $info = getimagesize($file['tmp_name']);
    return $info !== false && $info['mime'] === 'image/png';
}

function processUpload($fileInputName, $defaultName) {
    global $message, $messageType;
    if (isset($_FILES[$fileInputName]) && $_FILES[$fileInputName]['error'] === 0) {
        if (!isPNG($_FILES[$fileInputName])) {
            $message = 'A imagem deve ser um arquivo PNG.';
            $messageType = 'error';
            return '';
        }

        $fileTmpPath = $_FILES[$fileInputName]['tmp_name'];
        $fileName = $defaultName;

        if (move_uploaded_file($fileTmpPath, "uploads/$fileName")) {
            return $fileName;
        }
        
        $message = 'Erro ao fazer upload do arquivo.';
        $messageType = 'error';
        return '';
    }
    return '';
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && $_POST['action'] === 'update_config') {
    try {
        $success = true;
        
        // Processa os banners
        for ($i = 1; $i <= 4; $i++) {
            $bannerFile = processUpload("banner$i", "banner$i.png");
            if (!empty($message) && $messageType === 'error') {
                $success = false;
                break;
            }

            $existingBanner = $configManager->getBannerByOrder($i);
            $bannerData = [
                'titulo' => "Banner $i",
                'link' => '',
                'ordem' => $i,
                'status' => 1
            ];

            if ($bannerFile) {
                $bannerData['imagem'] = $bannerFile;
            } elseif ($existingBanner) {
                $bannerData['imagem'] = $existingBanner['imagem'];
            }

            if ($existingBanner) {
                $bannerData['id'] = $existingBanner['id'];
                $configManager->updateBanner($bannerData);
            } elseif ($bannerFile) {
                $configManager->addBanner($bannerData);
            }
        }

        if ($success && empty($message)) {
            $message = 'Banners atualizados com sucesso!';
            $messageType = 'success';
        }
    } catch (Exception $e) {
        $message = 'Ocorreu um erro ao salvar as configurações: ' . $e->getMessage();
        $messageType = 'error';
    }
}

$banners = $configManager->getBanners();
?>

<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Configurações do Launcher</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <?php include('nav_bar.php'); ?>

    <div class="container mt-4">
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title text-center" style="color: blue;">Adicionar banners</h5>
            </div>
            <div class="card-body">
                <form action="" method="POST" enctype="multipart/form-data" id="bannerForm">
                    <input type="hidden" name="action" value="update_config">
                    <div class="row mb-3">
                        <?php for ($i = 0; $i < 4; $i++): ?>
                            <div class="col-md-4">
                                <label class="form-label"><b style="color: blue;">Banner <?= $i + 1 ?></b></label>
                                <small class="form-text text-muted">
                                    <p style="color: blue;">Imagem recomendada (1920x1080 px).</p>
                                </small>
                                <input type="file" name="banner<?= $i + 1 ?>" class="form-control">
                                <?php if (isset($banners[$i]['imagem']) && !empty($banners[$i]['imagem'])): ?>
                                    <img src="uploads/<?= htmlspecialchars($banners[$i]['imagem']) ?>?v=<?= time() ?>" 
                                         class="mt-2" style="max-height: 50px;">
                                <?php endif; ?>
                            </div>
                        <?php endfor; ?>
                    </div>
                    <button type="submit" class="btn btn-primary">Salvar Configurações</button>
                </form>
            </div>
        </div>
    </div>

    <!-- Modal de Mensagem -->
    <div class="modal fade" id="messageModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Mensagem</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <p id="messageText"></p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-primary" data-bs-dismiss="modal">OK</button>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    
    <script>
    <?php if ($message): ?>
    let modalShown = false;
    
    document.addEventListener('DOMContentLoaded', function() {
        if (modalShown) return;
        
        const messageModal = new bootstrap.Modal(document.getElementById('messageModal'));
        const messageText = document.getElementById('messageText');
        messageText.textContent = <?= json_encode($message) ?>;
        messageText.className = <?= json_encode($messageType === 'error' ? 'text-danger' : 'text-success') ?>;
        
        modalShown = true;
        messageModal.show();

        // Se for sucesso, recarrega a página quando fechar o modal
        if (<?= json_encode($messageType === 'success') ?>) {
            const closeButton = document.querySelector('#messageModal .btn-close');
            if (closeButton) {
                closeButton.addEventListener('click', function() {
                    window.location.href = 'add_banner.php';
                }, { once: true });
            }
        }
    });
    <?php endif; ?>

    // Atualizar imagens para evitar cache
    function refreshImages() {
        document.querySelectorAll('img[src*="uploads/"]').forEach(img => {
            const [baseSrc] = img.src.split('?');
            img.src = `${baseSrc}?v=${new Date().getTime()}`;
        });
    }

    // Previne submissões duplicadas do formulário
    document.querySelector('#bannerForm').addEventListener('submit', function() {
        const submitButton = this.querySelector('button[type="submit"]');
        if (submitButton) {
            submitButton.disabled = true;
        }
    });
    </script>
</body>
</html>