<?php
require_once 'session_check.php';
require_once 'config.php';

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'classes/ConfigManager.php';
$configManager = new ConfigManager($pdo);

if ($_SERVER['REQUEST_METHOD'] === 'POST' && $_POST['action'] === 'update_config') {
    try {
        // Array para armazenar dados dos banners
        $bannersData = [];

        // Função para processar o upload de arquivos
        function processUpload($fileInputName, $defaultName)
        {
            if (isset($_FILES[$fileInputName]) && $_FILES[$fileInputName]['error'] === 0) {
                $fileTmpPath = $_FILES[$fileInputName]['tmp_name'];
                $fileName = $defaultName;

                // Move o arquivo para a pasta 'uploads'
                move_uploaded_file($fileTmpPath, "uploads/$fileName");

                return $fileName;
            }
            return '';
        }

        // Processa o logo
        $logo = processUpload('logo', 'logo.png');
        if ($logo) {
            $configManager->updateConfiguracoes(['logo' => $logo]);
        }

        // Processa cada banner e adiciona ou atualiza no banco
        for ($i = 1; $i <= 4; $i++) {
            $bannerFile = processUpload("banner$i", "banner$i.png");

            // Verifica se o banner já existe para essa ordem
            $existingBanner = $configManager->getBannerByOrder($i); // Assumindo que existe uma função `getBannerByOrder`

            // Define os dados do banner
            $bannerData = [
                'titulo' => "Banner $i",
                'link' => '', // Adicione links conforme necessário
                'ordem' => $i,
                'status' => 1
            ];

            // Se um novo arquivo foi enviado, define o campo 'imagem'; caso contrário, mantém o atual
            if ($bannerFile) {
                $bannerData['imagem'] = $bannerFile;
            } elseif ($existingBanner) {
                $bannerData['imagem'] = $existingBanner['imagem'];
            }

            // Se o banner já existir, atualiza-o; caso contrário, adiciona um novo
            if ($existingBanner) {
                $bannerData['id'] = $existingBanner['id'];
                $configManager->updateBanner($bannerData);
            } elseif ($bannerFile) {
                $configManager->addBanner($bannerData);
            }
        }

        // Redireciona com sucesso
        header('Location: add_banner.php');
    } catch (Exception $e) {
        // Redireciona com erro
        header('Location: add_banner.php');
    }
}

// Busca os banners ativos
$banners = $configManager->getBanners();
?>


<!DOCTYPE html>
<html lang="pt-BR">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Configurações do Launcher</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>

<body>
    <!--- Incluimos o menu navegação --->
    <?php include('nav_bar.php'); ?>

    <div class="container mt-4">

        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title" style="text-align:center; color: blue;">Adicionar banners</h5>
            </div>
            <div class="card-body">

                <form action="" method="POST" enctype="multipart/form-data">
                    <input type="hidden" name="action" value="update_config">
                    <div class="row mb-3">
                        <!-- Campos para cada banner -->
                        <?php for ($i = 0; $i < 4; $i++): ?>
                            <div class="col-md-4">
                                <label class="form-label"><b style="color: blue;">Banner <?= $i + 1 ?></b></label>
                                <small class="form-text text-muted">Imagen recomendado (1920x1080 px).</small>
                                <input type="file" name="banner<?= $i + 1 ?>" class="form-control">
                                <?php if (isset($banners[$i]['imagem']) && !empty($banners[$i]['imagem'])): ?>
                                <img src="uploads/<?= htmlspecialchars($banners[$i]['imagem']) ?>" class="mt-2" style="max-height: 50px;">
                            <?php endif; ?>
                        </div>
                    <?php endfor; ?>
                </div>
                <button type="submit" class="btn btn-primary">Salvar Configurações</button>
            </form>
        </div>

    </div>
</div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>