<?php
require_once 'session_check.php';
require_once 'config.php';
require_once 'classes/ConfigManager.php';

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

$configManager = new ConfigManager($pdo);
$errorMessage = ''; // Variável para armazenar a mensagem de erro

// Função para verificar se o arquivo é do tipo PNG
function isPNG($file)
{
    $info = getimagesize($file['tmp_name']);
    return $info !== false && $info['mime'] === 'image/png';
}

// Função para processar o upload de arquivos
function processUpload($fileInputName, $defaultName)
{
    global $errorMessage;
    if (isset($_FILES[$fileInputName]) && $_FILES[$fileInputName]['error'] === 0) {
        // Verifica se o arquivo é PNG
        if (!isPNG($_FILES[$fileInputName])) {
            $errorMessage = 'A imagem deve ser um arquivo PNG.'; // Define a mensagem de erro
            return ''; // Retorna vazio para evitar o upload
        }

        $fileTmpPath = $_FILES[$fileInputName]['tmp_name'];
        $fileName = $defaultName;

        // Move o arquivo para a pasta 'uploads'
        move_uploaded_file($fileTmpPath, "uploads/$fileName");
        return $fileName;
    }
    return '';
}

// Processamento do formulário de atualização de configuração
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $_POST['action'] === 'update_config') {
    try {
        // Processa o logo
        $logo = processUpload('logo', 'logo.png');
        if ($logo) {
            $configManager->updateConfiguracoes(['logo' => $logo]);
        }

        // Processa os banners
        for ($i = 1; $i <= 4; $i++) {
            $bannerFile = processUpload("banner$i", "banner$i.png");
            if ($errorMessage) break; // Interrompe o processo em caso de erro

            $existingBanner = $configManager->getBannerByOrder($i); // Obtém banner pela ordem
            $bannerData = [
                'titulo' => "Banner $i",
                'link' => '', // Adicione links conforme necessário
                'ordem' => $i,
                'status' => 1
            ];

            // Se um novo arquivo foi enviado, define o campo 'imagem'; caso contrário, mantém o atual
            if ($bannerFile) {
                $bannerData['imagem'] = $bannerFile;
            } elseif ($existingBanner) {
                $bannerData['imagem'] = $existingBanner['imagem'];
            }

            // Atualiza ou adiciona o banner
            if ($existingBanner) {
                $bannerData['id'] = $existingBanner['id'];
                $configManager->updateBanner($bannerData);
            } elseif ($bannerFile) {
                $configManager->addBanner($bannerData);
            }
        }

        if (!$errorMessage) {
            // Redireciona com sucesso
            header('Location: add_banner.php');
            exit;
        }
    } catch (Exception $e) {
        $errorMessage = 'Ocorreu um erro ao salvar as configurações.'; // Define a mensagem de erro
    }
}

// Busca os banners ativos
$banners = $configManager->getBanners();
?>

<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Configurações do Launcher</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <!-- Incluímos o menu navegação -->
    <?php include('nav_bar.php'); ?>

    <div class="container mt-4">
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title text-center" style="color: blue;">Adicionar banners</h5>
            </div>
            <div class="card-body">
                <!-- Exibe a mensagem de erro acima dos nomes dos banners -->
                <?php if ($errorMessage): ?>
                    <p class="text-danger text-center"><?= htmlspecialchars($errorMessage) ?></p>
                <?php endif; ?>

                <form action="" method="POST" enctype="multipart/form-data">
                    <input type="hidden" name="action" value="update_config">
                    <div class="row mb-3">
                        <!-- Campos para cada banner -->
                        <?php for ($i = 0; $i < 4; $i++): ?>
                            <div class="col-md-4">
                                <label class="form-label"><b style="color: blue;">Banner <?= $i + 1 ?></b></label>
                                <small class="form-text text-muted"><p style="color: blue;">Imagem recomendada (1920x1080 px).</p></small>
                                <input type="file" name="banner<?= $i + 1 ?>" class="form-control">
                                <?php if (isset($banners[$i]['imagem']) && !empty($banners[$i]['imagem'])): ?>
                                    <img src="uploads/<?= htmlspecialchars($banners[$i]['imagem']) ?>" class="mt-2" style="max-height: 50px;">
                                <?php endif; ?>
                            </div>
                        <?php endfor; ?>
                    </div>
                    <button type="submit" class="btn btn-primary">Salvar Configurações</button>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
