<?php
header('Content-Type: application/json');
include_once 'config/database.php';

try {
    // Validações
    if (!isset($_POST['version_code']) || !isset($_POST['version_name']) || !isset($_FILES['apk_file'])) {
        throw new Exception("Dados incompletos");
    }

    // Verifica o arquivo
    $file = $_FILES['apk_file'];
    if ($file['error'] !== UPLOAD_ERR_OK) {
        throw new Exception("Erro no upload do arquivo");
    }

    // Verifica se é um APK
    $fileType = strtolower(pathinfo($file['name'], PATHINFO_EXTENSION));
    if ($fileType != "apk") {
        throw new Exception("Apenas arquivos APK são permitidos");
    }

    // Gera nome único para o arquivo
    $apkFileName = 'launcher_v' . $_POST['version_name'] . '_' . time() . '.apk';
    $uploadPath = 'updates/' . $apkFileName;

    // Move o arquivo
    if (!move_uploaded_file($file['tmp_name'], $uploadPath)) {
        throw new Exception("Erro ao salvar arquivo");
    }

    // Conecta ao banco
    $database = new Database();
    $db = $database->getConnection();

    // Verifica se já existe uma versão com código maior ou igual
    $check_query = "SELECT version_code FROM launcher_updates WHERE version_code >= :version_code";
    $check_stmt = $db->prepare($check_query);
    $check_stmt->bindParam(":version_code", $_POST['version_code']);
    $check_stmt->execute();

    if ($check_stmt->rowCount() > 0) {
        unlink($uploadPath); // Remove o arquivo
        throw new Exception("Já existe uma versão igual ou superior cadastrada");
    }

    // Insere no banco
    $query = "INSERT INTO launcher_updates 
              (version_code, version_name, apk_file, changelog, force_update, status) 
              VALUES 
              (:version_code, :version_name, :apk_file, :changelog, :force_update, :status)";

    $stmt = $db->prepare($query);

    $force_update = isset($_POST['force_update']) ? 1 : 0;
    $status = isset($_POST['status']) ? 1 : 0;

    $stmt->bindParam(":version_code", $_POST['version_code']);
    $stmt->bindParam(":version_name", $_POST['version_name']);
    $stmt->bindParam(":apk_file", $apkFileName);
    $stmt->bindParam(":changelog", $_POST['changelog']);
    $stmt->bindParam(":force_update", $force_update);
    $stmt->bindParam(":status", $status);

    if ($stmt->execute()) {
        header("Location: form_update.php?success=1");
    } else {
        unlink($uploadPath); // Remove o arquivo em caso de erro
        throw new Exception("Erro ao inserir no banco de dados");
    }

} catch(Exception $e) {
    header("Location: form_update.php?error=" . urlencode($e->getMessage()));
}
?>