<?php
header('Content-Type: application/json');
include_once '../config/database.php';

try {
    // Validar dados recebidos
    $mac_address = isset($_POST['mac_address']) ? trim($_POST['mac_address']) : '';
    $device_name = isset($_POST['device_name']) ? trim($_POST['device_name']) : '';

    // Validaes bsicas
    if (empty($mac_address) || empty($device_name)) {
        throw new Exception("MAC e nome do dispositivo so obrigatrios");
    }

    // Validar formato do MAC
    if (!preg_match('/^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/', $mac_address)) {
        throw new Exception("Formato de MAC invlido");
    }

    $database = new Database();
    $db = $database->getConnection();

    // Verificar se o MAC j existe
    $check_query = "SELECT id FROM devices WHERE mac_address = :mac_address";
    $check_stmt = $db->prepare($check_query);
    $check_stmt->bindParam(":mac_address", $mac_address);
    $check_stmt->execute();

    if ($check_stmt->rowCount() > 0) {
        throw new Exception("Este MAC j est cadastrado");
    }

    // Inserir novo dispositivo
    $query = "INSERT INTO devices (mac_address, device_name, status) VALUES (:mac_address, :device_name, 1)";
    $stmt = $db->prepare($query);
    $stmt->bindParam(":mac_address", $mac_address);
    $stmt->bindParam(":device_name", $device_name);

    if ($stmt->execute()) {
        // Redirecionar de volta para a pgina de dispositivos
        header("Location: devices.php?success=1");
        exit();
    } else {
        throw new Exception("Erro ao cadastrar dispositivo");
    }

} catch (Exception $e) {
    // Redirecionar com mensagem de erro
    header("Location: devices.php?error=" . urlencode($e->getMessage()));
    exit();
}
?>