<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");

include_once '../config/database.php';

try {
    $database = new Database();
    $db = $database->getConnection();

    $mac_address = isset($_GET['mac']) ? $_GET['mac'] : '';
    
    if (empty($mac_address)) {
        throw new Exception("MAC address não fornecido");
    }

    // Query modificada para verificar todos os status
    $query = "SELECT a.* 
              FROM apps a 
              INNER JOIN device_apps da ON da.app_id = a.id 
              INNER JOIN devices d ON d.id = da.device_id 
              WHERE d.mac_address = :mac 
              AND d.status = 1  -- Verifica status do device
              AND da.status = 1  -- Verifica status da relação device_app
              AND a.status = 1   -- Verifica status do app
              ORDER BY a.ordem ASC";

    $stmt = $db->prepare($query);
    $stmt->bindParam(":mac", $mac_address);
    $stmt->execute();

    $apps = array();
    
    while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $app_item = array(
            "id" => $row['id'],
            "nome" => $row['nome'],
            "pacote" => $row['pacote'],
            "categoria" => $row['categoria'],
            "icone_url" => $row['icone'],
            "ordem" => $row['ordem'],
            "apk_url" => $row['apk_url'],
            "status" => $row['status']
        );
        array_push($apps, $app_item);
    }

    echo json_encode([
        "status" => "success",
        "apps" => $apps
    ]);

} catch(PDOException $e) {
    echo json_encode([
        "status" => "error",
        "message" => "Database error: " . $e->getMessage()
    ]);
} catch(Exception $e) {
    echo json_encode([
        "status" => "error",
        "message" => $e->getMessage()
    ]);
}
?>