<?php
class AppsManager
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    // public function addApp($nome, $pacote, $categoria, $ordem, $icone)
    // {
    //     $stmt = $this->pdo->prepare("INSERT INTO apps (nome, pacote, categoria, ordem, icone, apk_url) VALUES (?, ?, ?, ?, ?, ?)");
    //     return $stmt->execute([$nome, $pacote, $categoria, $ordem, $icone, $apk_url]);
    // }

    public function addApp($nome, $pacote, $categoria, $ordem, $icone, $apk_url = '')
    {
        try {
            // Log para debug
            error_log("Iniciando inserção no banco de dados");
            error_log("Dados recebidos: nome=$nome, pacote=$pacote, apk_url=$apk_url");

            $sql = "INSERT INTO apps (nome, pacote, categoria, ordem, icone, apk_url) 
                    VALUES (:nome, :pacote, :categoria, :ordem, :icone, :apk_url)";
            
            $stmt = $this->pdo->prepare($sql);
            
            $params = [
                ':nome' => $nome,
                ':pacote' => $pacote,
                ':categoria' => $categoria,
                ':ordem' => $ordem,
                ':icone' => $icone,
                ':apk_url' => $apk_url
            ];

            // Log dos parâmetros
            error_log("Executando query com parâmetros: " . print_r($params, true));

            if (!$stmt->execute($params)) {
                error_log("Erro na execução da query: " . print_r($stmt->errorInfo(), true));
                return false;
            }

            error_log("Inserção realizada com sucesso");
            return true;

        } catch (PDOException $e) {
            error_log("Erro PDO: " . $e->getMessage());
            return false;
        }
    }

public function getApps()
{
    try {
        $stmt = $this->pdo->query("SELECT * FROM apps ORDER BY ordem ASC");
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        error_log("Erro ao buscar apps: " . $e->getMessage());
        return [];
    }
}

public function updateApp($id, $nome, $pacote, $categoria, $ordem, $icone = null) {
    try {
        // Prepara a query base
        $query = "UPDATE apps SET 
                  nome = :nome, 
                  pacote = :pacote, 
                  categoria = :categoria, 
                  ordem = :ordem";
        
        $params = [
            ':id' => $id,
            ':nome' => $nome,
            ':pacote' => $pacote,
            ':categoria' => $categoria,
            ':ordem' => $ordem
        ];
        
        // Adiciona o ícone à query apenas se um novo for fornecido
        if ($icone !== null) {
            $query .= ", icone = :icone";
            $params[':icone'] = $icone;
        }
        
        $query .= " WHERE id = :id";
        
        $stmt = $this->pdo->prepare($query);
        return $stmt->execute($params);
    } catch (PDOException $e) {
        error_log("Erro ao atualizar app: " . $e->getMessage());
        return false;
    }
}

// Método auxiliar para obter o ícone atual
public function getAppIcon($id) {
    try {
        $stmt = $this->pdo->prepare("SELECT icone FROM apps WHERE id = ?");
        $stmt->execute([$id]);
        $result = $stmt->fetch(PDO::FETCH_ASSOC);
        return $result ? $result['icone'] : null;
    } catch (PDOException $e) {
        error_log("Erro ao buscar ícone: " . $e->getMessage());
        return null;
    }
}




  public function deleteApp($id)
{
    try {
        // Inicia a transação
        $this->pdo->beginTransaction();

        // Primeiro recupera o ícone antes de deletar o registro
        $stmt = $this->pdo->prepare("SELECT icone FROM apps WHERE id = :id");
        $stmt->bindParam(':id', $id, PDO::PARAM_INT);
        $stmt->execute();
        $icone = $stmt->fetchColumn();

        // Primeiro deleta os registros relacionados na tabela device_apps
        $stmt = $this->pdo->prepare("DELETE FROM device_apps WHERE app_id = :id");
        $stmt->bindParam(':id', $id, PDO::PARAM_INT);
        $stmt->execute();

        // Depois deleta o app
        $stmt = $this->pdo->prepare("DELETE FROM apps WHERE id = :id");
        $stmt->bindParam(':id', $id, PDO::PARAM_INT);
        $result = $stmt->execute();

        if ($result) {
            // Se tiver ícone e ele existir no sistema de arquivos, tenta removê-lo
            if ($icone && file_exists('uploads/' . $icone)) {
                @unlink('uploads/' . $icone);
            }
            
            // Confirma a transação
            $this->pdo->commit();
            return true;
        }

        // Se a deleção falhou, faz rollback
        $this->pdo->rollBack();
        return false;

    } catch (PDOException $e) {
        // Em caso de erro, faz rollback se estiver em uma transação
        if ($this->pdo->inTransaction()) {
            $this->pdo->rollBack();
        }
        error_log("Erro ao excluir o app (ID: $id): " . $e->getMessage());
        return false;
    }
}

    // public function getApps()
    // {
    //     $sql = "SELECT * FROM apps WHERE status = 1 ORDER BY ordem";
    //     $stmt = $this->pdo->query($sql);
    //     return $stmt->fetchAll(PDO::FETCH_ASSOC);
    // }

    public function getApp($id)
    {
        $sql = "SELECT * FROM apps WHERE id = :id AND status = 1";
        $stmt = $this->pdo->prepare($sql);
        $stmt->execute([':id' => $id]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
}
