<?php
class ConfigManager {
    private $pdo;
    
    public function __construct($pdo) {
        $this->pdo = $pdo;
    }
    
    // Função adicionar banner, funcionando.
    public function addBanner($data) {
        try {
        // Define os dados padrão caso não sejam fornecidos
            $bannerData = [
                ':titulo' => $data['titulo'] ?? '',
                ':imagem' => $data['imagem'] ?? '',
                ':link' => $data['link'] ?? '',
                ':ordem' => $data['ordem'] ?? 0,
                ':status' => $data['status'] ?? 1,
                ':created_at' => date('Y-m-d H:i:s'),
                ':updated_at' => date('Y-m-d H:i:s')
            ];

        // Consulta SQL para inserir o novo banner
            $sql = "INSERT INTO banners (titulo, imagem, link, ordem, status, created_at, updated_at) 
            VALUES (:titulo, :imagem, :link, :ordem, :status, :created_at, :updated_at)";

            $stmt = $this->pdo->prepare($sql);
            return $stmt->execute($bannerData);
        } catch (Exception $e) {
            throw $e;
        }
    }

    // Função para atuaizar os banners, funcionando.
    public function updateBanner($data) {
        try {
        // Define os dados padrão para atualização
            $bannerData = [
                ':id' => $data['id'],
                ':titulo' => $data['titulo'] ?? '',
                ':imagem' => $data['imagem'] ?? '',
                ':link' => $data['link'] ?? '',
                ':ordem' => $data['ordem'] ?? 0,
                ':status' => $data['status'] ?? 1,
                ':updated_at' => date('Y-m-d H:i:s')
            ];

        // Consulta SQL para atualizar o banner com o ID especificado
            $sql = "UPDATE banners 
            SET titulo = :titulo,
            imagem = :imagem,
            link = :link,
            ordem = :ordem,
            status = :status,
            updated_at = :updated_at
            WHERE id = :id";

            $stmt = $this->pdo->prepare($sql);
            return $stmt->execute($bannerData);
        } catch (Exception $e) {
            throw $e;
        }
    }


    // Função para buscar os banners, funcionando.
    public function getBanners() {
        try {
        // Consulta SQL para buscar todos os banners com status ativo
            $sql = "SELECT id, titulo, imagem, link, ordem, status FROM banners WHERE status = 1 ORDER BY ordem ASC";
            $stmt = $this->pdo->query($sql);

        // Retorna todos os banners em formato de array associativo
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            throw $e;
        }
    }

    // Função para buscar banners em ordem, funcionando.
    public function getBannerByOrder($ordem) {
        try {
            $sql = "SELECT * FROM banners WHERE ordem = :ordem LIMIT 1";
            $stmt = $this->pdo->prepare($sql);
            $stmt->execute([':ordem' => $ordem]);
            return $stmt->fetch(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    // Função update, funcionando.
    public function updateApp($data) {
        try {
        // Monta a consulta SQL para atualização
            $sql = "UPDATE apps SET nome = :nome, pacote = :pacote, categoria = :categoria, ordem = :ordem";
            
        // Adiciona o ícone se houver um novo arquivo
            if (!empty($data['icone'])) {
                $sql .= ", icone = :icone";
            }

            $sql .= " WHERE id = :id";

            $stmt = $this->pdo->prepare($sql);

        // Bind dos parâmetros
            $stmt->bindParam(':id', $data['id']);
            $stmt->bindParam(':nome', $data['nome']);
            $stmt->bindParam(':pacote', $data['pacote']);
            $stmt->bindParam(':categoria', $data['categoria']);
            $stmt->bindParam(':ordem', $data['ordem']);

            if (!empty($data['icone'])) {
                $stmt->bindParam(':icone', $data['icone']);
            }

        // Executa a consulta
            return $stmt->execute();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    // Função delete, funcionando.
    public function deleteApp($id) {
        try {
        // Consulta SQL para excluir o registro com o ID especificado
            $sql = "DELETE FROM apps WHERE id = :id";
            $stmt = $this->pdo->prepare($sql);
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);

            return $stmt->execute();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    // Função para buscar as configurações, funcionando
    public function getConfiguracoes() {
    try {
        // Consulta SQL para buscar as configurações
        $sql = "SELECT logo, background, qr_code FROM configuracoes LIMIT 1";
        $stmt = $this->pdo->query($sql);
        $config = $stmt->fetch(PDO::FETCH_ASSOC);

        // Retorna as configurações ou valores padrão se não forem encontradas
        return $config ?: [
            'logo' => '',
            'background' => '',
            'qr_code' => ''
        ];
    } catch (Exception $e) {
        throw $e;
    }
}





    
    public function updateConfiguracoes($data) {
        try {
            // Verifica se já existe uma configuração
            $config = $this->getConfiguracoes();
            
            // Mantém os valores antigos caso não sejam fornecidos novos
            $updateData = [
                ':logo' => isset($data['logo']) && !empty($data['logo']) ? $data['logo'] : $config['logo'],
                ':background' => isset($data['background']) && !empty($data['background']) ? $data['background'] : $config['background'],
                ':qr_code' => isset($data['qr_code']) && !empty($data['qr_code']) ? $data['qr_code'] : $config['qr_code'],
                ':qr_code_texto' => $data['qr_code_texto'] ?? $config['qr_code_texto'],
                ':cor_primaria' => $data['cor_primaria'] ?? $config['cor_primaria'],
                ':cor_secundaria' => $data['cor_secundaria'] ?? $config['cor_secundaria'],
                ':texto_superior' => $data['texto_superior'] ?? $config['texto_superior']
            ];

            if ($config) {
                $sql = "UPDATE configuracoes SET 
                logo = :logo,
                background = :background,
                qr_code = :qr_code,
                qr_code_texto = :qr_code_texto,
                cor_primaria = :cor_primaria,
                cor_secundaria = :cor_secundaria,
                texto_superior = :texto_superior
                WHERE status = 1";
            } else {
                $sql = "INSERT INTO configuracoes 
                (logo, background, qr_code, qr_code_texto, cor_primaria, cor_secundaria, texto_superior, status) 
                VALUES 
                (:logo, :background, :qr_code, :qr_code_texto, :cor_primaria, :cor_secundaria, :texto_superior, 1)";
            }
            
            $stmt = $this->pdo->prepare($sql);
            return $stmt->execute($updateData);
        } catch (Exception $e) {
            throw $e;
        }
    }

}