<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'session_check.php';
require_once 'config.php';

function isPNG($file) {
    $info = getimagesize($file['tmp_name']);
    return $info !== false && $info['mime'] === 'image/png';
}

$configManager = new ConfigManager($pdo);
$config = $configManager->getConfiguracoes();
$message = '';
$messageType = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';
    if ($action === 'update_config') {
        try {
            $updateData = [
                'qr_code_texto' => $_POST['qr_code_texto'] ?? '',
                'cor_primaria' => $_POST['cor_primaria'] ?? '#0066CC',
                'cor_secundaria' => $_POST['cor_secundaria'] ?? '#003399',
                'texto_superior' => $_POST['texto_superior'] ?? ''
            ];

            $hasErrors = false;

            // Verifica e processa o upload do logo
            if (isset($_FILES['logo']) && $_FILES['logo']['error'] === 0) {
                if (!isPNG($_FILES['logo'])) {
                    $message = 'Logo deve ser uma imagem PNG';
                    $messageType = 'error';
                    $hasErrors = true;
                } else {
                    if (file_exists('uploads/logo.png')) {
                        unlink('uploads/logo.png');
                    }
                    move_uploaded_file($_FILES['logo']['tmp_name'], 'uploads/logo.png');
                    $updateData['logo'] = 'logo.png';
                }
            }

            // Verifica e processa o upload do background
            if (isset($_FILES['background']) && $_FILES['background']['error'] === 0) {
                if (!isPNG($_FILES['background'])) {
                    $message = 'Background deve ser uma imagem PNG';
                    $messageType = 'error';
                    $hasErrors = true;
                } else {
                    if (file_exists('uploads/background.png')) {
                        unlink('uploads/background.png');
                    }
                    move_uploaded_file($_FILES['background']['tmp_name'], 'uploads/background.png');
                    $updateData['background'] = 'background.png';
                }
            }

            // Verifica e processa o upload do QR Code
            if (isset($_FILES['qr_code']) && $_FILES['qr_code']['error'] === 0) {
                if (!isPNG($_FILES['qr_code'])) {
                    $message = 'QR Code deve ser uma imagem PNG';
                    $messageType = 'error';
                    $hasErrors = true;
                } else {
                    if (file_exists('uploads/qrcode.png')) {
                        unlink('uploads/qrcode.png');
                    }
                    move_uploaded_file($_FILES['qr_code']['tmp_name'], 'uploads/qrcode.png');
                    $updateData['qr_code'] = 'qrcode.png';
                }
            }

            if (!$hasErrors) {
                $configManager->updateConfiguracoes($updateData);
                $message = "Configurações atualizadas com sucesso!";
                $messageType = "success";
            }
        } catch (Exception $e) {
            $message = $e->getMessage();
            $messageType = "error";
        }
    } elseif ($action === 'update_bloqueio') {
        try {
            $stmt = $pdo->prepare("SELECT senha_admin FROM block_configuracoes WHERE id = 1");
            $stmt->execute();
            $currentPassword = $stmt->fetchColumn();

            $senha = !empty($_POST['senha_admin']) ? $_POST['senha_admin'] : $currentPassword;
            $bloquear_configs = isset($_POST['bloquear_configs']) ? 1 : 0;
            $bloquear_apps = isset($_POST['bloquear_apps_sistema']) ? 1 : 0;

            $stmt = $pdo->prepare("INSERT INTO block_configuracoes (id, senha_admin, bloquear_configs, bloquear_apps_sistema) 
                VALUES (1, ?, ?, ?) ON DUPLICATE KEY UPDATE 
                senha_admin = VALUES(senha_admin), 
                bloquear_configs = VALUES(bloquear_configs), 
                bloquear_apps_sistema = VALUES(bloquear_apps_sistema)");
            $stmt->execute([$senha, $bloquear_configs, $bloquear_apps]);

            $message = "Configurações atualizadas com sucesso!";
            $messageType = "success";
        } catch (Exception $e) {
            $message = $e->getMessage();
            $messageType = "error";
        }
    }
}

$bloqueioConfig = $pdo->query("SELECT * FROM block_configuracoes LIMIT 1")->fetch();
?>

<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Configurações do Launcher</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>

<body>
    <?php include('nav_bar.php'); ?>

    <div class="container mt-4">
        <!-- Cards de configuração (mantenha o HTML original) -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title text-center text-primary">Configurações</h5>
            </div>
            <div class="card-body">
                <form action="" method="POST" enctype="multipart/form-data" id="configForm">
                    <input type="hidden" name="action" value="update_config">

                    <div class="row mb-3">
                        <div class="col-md-4">
                            <label class="form-label text-primary"><b>Logo</b> (200x200 px)</label>
                            <input type="file" name="logo" class="form-control">
                            <?php if (!empty($config['logo'])): ?>
                                <img src="uploads/<?= htmlspecialchars($config['logo']) ?>?v=<?= time() ?>" class="mt-2" style="max-height: 50px; border: 2px solid #007bff; border-radius: 5px;">
                            <?php endif; ?>
                        </div>

                        <div class="col-md-4">
                            <label class="form-label text-primary"><b>Background</b> (1920x1080 px)</label>
                            <input type="file" name="background" class="form-control">
                            <?php if (!empty($config['background'])): ?>
                                <img src="uploads/<?= htmlspecialchars($config['background']) ?>?v=<?= time() ?>" class="mt-2" style="max-height: 50px">
                            <?php endif; ?>
                        </div>

                        <div class="col-md-4">
                            <label class="form-label text-primary"><b>QR Code</b> (300x300 px)</label>
                            <input type="file" name="qr_code" class="form-control">
                            <?php if (!empty($config['qr_code'])): ?>
                                <img src="uploads/<?= htmlspecialchars($config['qr_code']) ?>?v=<?= time() ?>" class="mt-2" style="max-height: 50px">
                            <?php endif; ?>
                        </div>
                    </div>

                    <button type="submit" class="btn btn-primary">Salvar Configurações</button>
                </form>
            </div>
        </div>

        <div class="card mt-4 mb-4">
            <div class="card-header">
                <h5 class="card-title text-center text-primary">Configurações de Bloqueio</h5>
            </div>
            <div class="card-body">
                <form method="POST" id="bloqueioForm">
                    <input type="hidden" name="action" value="update_bloqueio">
                    <div class="mb-3">
                        <label class="form-label"><b style="color: blue;">Senha do Administrador</b></label>
                        <div class="col-md-2">
                            <input type="text" name="senha_admin" class="form-control" value="">
                            <?php if (!empty($bloqueioConfig['senha_admin'])): ?>
                                <small class="form-text text-muted">Senha atual: <b><?= htmlspecialchars($bloqueioConfig['senha_admin']) ?></b></small>
                            <?php endif; ?>
                        </div>
                    </div>

                    <div class="form-check mb-3">
                        <input type="checkbox" name="bloquear_configs" class="form-check-input" 
                        <?= isset($bloqueioConfig['bloquear_configs']) && $bloqueioConfig['bloquear_configs'] == 1 ? 'checked' : '' ?>>
                        <label class="form-check-label">Bloquear acesso às configurações</label>
                    </div>

                    <div class="form-check mb-3">
                        <input type="checkbox" name="bloquear_apps_sistema" class="form-check-input"
                        <?= isset($bloqueioConfig['bloquear_apps_sistema']) && $bloqueioConfig['bloquear_apps_sistema'] == 1 ? 'checked' : '' ?>>
                        <label class="form-check-label">Bloquear acesso aos apps do sistema</label>
                    </div>

                    <button type="submit" class="btn btn-primary">Salvar</button>
                </form>
            </div>
        </div>
    </div>

    <!-- Modal de Mensagem -->
    <div class="modal fade" id="messageModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Mensagem</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <p id="messageText"></p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-primary" data-bs-dismiss="modal">OK</button>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    
<script>
    // Exibir mensagem modal se houver
    <?php if ($message): ?>
    let modalShown = false;  // Flag para controlar se o modal já foi mostrado
    
    document.addEventListener('DOMContentLoaded', function() {
        // Se o modal já foi mostrado, não mostra novamente
        if (modalShown) return;
        
        const messageModal = new bootstrap.Modal(document.getElementById('messageModal'));
        const messageText = document.getElementById('messageText');
        messageText.textContent = <?= json_encode($message) ?>;
        messageText.className = <?= json_encode($messageType === 'error' ? 'text-danger' : 'text-success') ?>;
        
        modalShown = true;  // Marca que o modal foi mostrado
        messageModal.show();

        // Se for mensagem de sucesso, fecha o modal e recarrega apenas uma vez
        if (<?= json_encode($messageType === 'success') ?>) {
            const closeButton = document.querySelector('#messageModal .btn-close');
            if (closeButton) {
                closeButton.addEventListener('click', function() {
                    window.location.href = 'configuracoes.php';
                }, { once: true });  // Garante que o evento só será executado uma vez
            }
        }
    });
    <?php endif; ?>

    // Atualizar imagens para evitar cache
    function refreshImages() {
        document.querySelectorAll('img[src*="uploads/"]').forEach(img => {
            const [baseSrc] = img.src.split('?');
            img.src = `${baseSrc}?v=${new Date().getTime()}`;
        });
    }

    // Previne submissões duplicadas dos formulários
    document.querySelectorAll('form').forEach(form => {
        form.addEventListener('submit', function() {
            const submitButton = this.querySelector('button[type="submit"]');
            if (submitButton) {
                submitButton.disabled = true;
            }
        });
    });
</script>
</body>
</html>