<?php
// Ensure only POST requests are processed
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('HTTP/1.1 405 Method Not Allowed');
    exit(json_encode([
        'success' => false,
        'message' => 'Method not allowed'
    ]));
}

// Set proper content type for JSON response
header('Content-Type: application/json');

try {
    // Validate filename parameter
    if (!isset($_POST['filename']) || empty($_POST['filename'])) {
        throw new Exception('Nome do arquivo não fornecido');
    }

    $filename = basename($_POST['filename']); // Get only the filename part
    $filepath = __DIR__ . '/apks/' . $filename;

    // Security validations
    if (!preg_match('/^[a-zA-Z0-9._-]+\.apk$/i', $filename)) {
        throw new Exception('Nome de arquivo inválido');
    }

    // Verify file exists and is within the apks directory
    if (!file_exists($filepath) || !is_file($filepath)) {
        throw new Exception('Arquivo não encontrado');
    }

    // Check if file is writable
    if (!is_writable($filepath)) {
        throw new Exception('Permissão negada para excluir o arquivo');
    }

    // Attempt to delete the file
    if (unlink($filepath)) {
        echo json_encode([
            'success' => true,
            'message' => 'Arquivo excluído com sucesso'
        ]);
    } else {
        throw new Exception('Erro ao excluir arquivo');
    }

} catch (Exception $e) {
    http_response_code(400);
    echo json_encode([
        'success' => false,
        'message' => $e->getMessage()
    ]);
}