<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'session_check.php';
require_once 'config.php';
require_once 'classes/ConfigManager.php';
include_once 'config/database.php';



$database = new Database();
$db = $database->getConnection();

// Função para retornar resposta JSON
function jsonResponse($success, $message, $data = null) {
    header('Content-Type: application/json');
    echo json_encode([
        'success' => $success,
        'message' => $message,
        'data' => $data
    ]);
    exit;
}

// Processamento de formulários
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        try {
            switch ($_POST['action']) {
                case 'add':
                $mac = trim($_POST['mac_address'] ?? '');
                $name = trim($_POST['device_name'] ?? '');
                
                if (empty($mac) || empty($name)) {
                    throw new Exception("Todos os campos são obrigatórios.");
                }

                if (!preg_match('/^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/', $mac)) {
                    throw new Exception("Formato de MAC Address inválido");
                }

                    // Verifica MAC duplicado
                $stmt = $db->prepare("SELECT id FROM devices WHERE mac_address = ?");
                $stmt->execute([$mac]);
                if ($stmt->fetch()) {
                    throw new Exception("Este MAC Address já está cadastrado");
                }

                $stmt = $db->prepare("INSERT INTO devices (mac_address, device_name, status) VALUES (?, ?, 1)");
                if (!$stmt->execute([$mac, $name])) {
                    throw new Exception("Erro ao cadastrar dispositivo");
                }

                if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && 
                    $_SERVER['HTTP_X_REQUESTED_WITH'] === 'XMLHttpRequest') {
                    jsonResponse(true, "Dispositivo cadastrado com sucesso!");
            }
            break;

            case 'update':
            $id = filter_var($_POST['device_id'], FILTER_VALIDATE_INT);
            $mac = trim($_POST['mac_address'] ?? '');
            $name = trim($_POST['device_name'] ?? '');
            
            if (!$id) {
                throw new Exception("ID do dispositivo inválido");
            }

                    // Busca dados atuais
            $stmt = $db->prepare("SELECT * FROM devices WHERE id = ?");
            $stmt->execute([$id]);
            $currentDevice = $stmt->fetch(PDO::FETCH_ASSOC);

            if (!$currentDevice) {
                throw new Exception("Dispositivo não encontrado");
            }

                    // Mantém valores atuais se campos estiverem vazios
            $mac = empty($mac) ? $currentDevice['mac_address'] : $mac;
            $name = empty($name) ? $currentDevice['device_name'] : $name;

                    // Valida MAC se foi alterado
            if ($mac !== $currentDevice['mac_address']) {
                if (!preg_match('/^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/', $mac)) {
                    throw new Exception("Formato de MAC Address inválido");
                }

                        // Verifica MAC duplicado
                $stmt = $db->prepare("SELECT id FROM devices WHERE mac_address = ? AND id != ?");
                $stmt->execute([$mac, $id]);
                if ($stmt->fetch()) {
                    throw new Exception("Este MAC Address já está em uso");
                }
            }

            $stmt = $db->prepare("UPDATE devices SET mac_address = ?, device_name = ? WHERE id = ?");
            if (!$stmt->execute([$mac, $name, $id])) {
                throw new Exception("Erro ao atualizar dispositivo");
            }

            if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && 
                $_SERVER['HTTP_X_REQUESTED_WITH'] === 'XMLHttpRequest') {
                jsonResponse(true, "Dispositivo atualizado com sucesso!");
        }
        break;

        case 'delete':
        $id = filter_var($_POST['device_id'], FILTER_VALIDATE_INT);
        
        if (!$id) {
            throw new Exception("ID do dispositivo inválido");
        }

        $stmt = $db->prepare("DELETE FROM device_apps WHERE device_id = ?");
        $stmt->execute([$id]);
        
        $stmt = $db->prepare("DELETE FROM devices WHERE id = ?");
        if (!$stmt->execute([$id])) {
            throw new Exception("Erro ao excluir dispositivo");
        }

        if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && 
            $_SERVER['HTTP_X_REQUESTED_WITH'] === 'XMLHttpRequest') {
            jsonResponse(true, "Dispositivo excluído com sucesso!");
    }
    break;
}
} catch (Exception $e) {
    if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && 
        $_SERVER['HTTP_X_REQUESTED_WITH'] === 'XMLHttpRequest') {
        jsonResponse(false, $e->getMessage());
}
$error = $e->getMessage();
}
}
}

// Busca lista de dispositivos
$query = "SELECT * FROM devices ORDER BY device_name";
$stmt = $db->prepare($query);
$stmt->execute();
$devices = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gerenciar Dispositivos</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.css" rel="stylesheet">
    <style>
        .device-container { margin-bottom: 2rem; padding: 1rem; border: 1px solid #dee2e6; border-radius: 0.25rem; }
        .device-header { display: flex; justify-content: space-between; align-items: center; margin-bottom: 1rem; }
        .device-status { margin: 1rem 0; }
        .app-list { margin-top: 1rem; }
        .form-check-input { cursor: pointer; }
    </style>
    <style>
        #toast-container > div {
            opacity: 1;
        }
        .toast-success {
            background-color: #28a745 !important;
        }
        .toast-error {
            background-color: #dc3545 !important;
        }
        .device-status {
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }
        .form-check-label {
            font-weight: 500;
        }
    </style>

    <style>
        .toast-success {
            background-color: #28a745 !important;
            color: white !important;
        }

        #messageContainer {
            position: fixed;
            top: 20px;
            right: 20px;
            z-index: 9999;
            min-width: 250px;
        }

        .alert {
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 10px;
            animation: fadeIn 0.3s ease-in;
        }

        @keyframes fadeIn {
            from { opacity: 0; transform: translateY(-10px); }
            to { opacity: 1; transform: translateY(0); }
        }

/* Estilo para os checkboxes */
.form-check-input:checked {
    background-color: #28a745;
    border-color: #28a745;
}
</style>
</head>

<body>
    <div id="messageContainer"></div>
    <?php include('nav_bar.php'); ?>

    <div class="container mt-4">
        <!-- Formulário de Adicionar -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title m-0">Adicionar Dispositivo</h5>
            </div>
            <div class="card-body">
                <form id="addDeviceForm" class="needs-validation" novalidate>
                    <input type="hidden" name="action" value="add">
                    <div class="mb-3">
                        <label class="form-label">MAC Address:</label>
                        <input type="text" name="mac_address" class="form-control mac-input" required
                        pattern="([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})"
                        placeholder="00:11:22:33:44:55"
                        maxlength="17">
                        <div class="invalid-feedback">
                            Por favor, insira um MAC válido no formato XX:XX:XX:XX:XX:XX
                        </div>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Nome do Dispositivo:</label>
                        <input type="text" name="device_name" class="form-control" required 
                        placeholder="Ex: TV Sala">
                        <div class="invalid-feedback">
                            Por favor, insira um nome para o dispositivo
                        </div>
                    </div>
                    <button type="submit" class="btn btn-primary">Adicionar</button>
                </form>
            </div>
        </div>

        <!-- Lista de Dispositivos -->
        <div class="card">
            <div class="card-header">
                <h5 class="card-title m-0">Dispositivos Cadastrados</h5>
            </div>
            <div class="card-body" id="devicesList">
                <?php if (empty($devices)): ?>
                    <p class="text-center text-muted">Nenhum dispositivo cadastrado.</p>
                <?php else: ?>
                    <?php foreach ($devices as $device): ?>
                        <div class="device-container">

                            <div class="device-header">
                                <h5 class="text-primary m-0">
                                    <?= htmlspecialchars($device['device_name']) ?>
                                    <small class="text-muted">(MAC: <?= htmlspecialchars($device['mac_address']) ?>)</small>
                                </h5>
                                <button class="btn btn-sm btn-primary edit-device"
                                data-id="<?= $device['id'] ?>"
                                data-name="<?= htmlspecialchars($device['device_name']) ?>"
                                data-mac="<?= htmlspecialchars($device['mac_address']) ?>">
                                Editar
                            </button>
                            <button class="btn btn-sm btn-danger delete-device ms-2"
                            data-id="<?= $device['id'] ?>"
                            data-name="<?= htmlspecialchars($device['device_name']) ?>">
                            Excluir
                        </button>
                    </div>

                    <div class="device-status">
                        <div class="form-check form-switch">
                            <input type="checkbox" class="form-check-input device-status-toggle"
                            data-device="<?= $device['id'] ?>"
                            <?= $device['status'] == 1 ? 'checked' : '' ?>>
                            <label class="form-check-label ms-2 <?= $device['status'] == 1 ? 'text-success' : 'text-danger' ?>"
                             id="status-label-<?= $device['id'] ?>">
                             <?= $device['status'] == 1 ? 'Ativo' : 'Desativado' ?>
                         </label>
                     </div>
                 </div>

                 <!-- Apps do dispositivo -->
                 <div class="app-list">
                    <?php
                    $apps_query = "SELECT a.*, 
                    CASE WHEN (da.id IS NOT NULL AND da.status = 1) THEN 1 ELSE 0 END as is_enabled 
                    FROM apps a 
                    LEFT JOIN device_apps da ON da.app_id = a.id AND da.device_id = :device_id
                    WHERE a.status = 1 
                    ORDER BY a.categoria, a.ordem, a.nome";
                    $apps_stmt = $db->prepare($apps_query);
                    $apps_stmt->bindParam(":device_id", $device['id']);
                    $apps_stmt->execute();

                    $current_category = '';
                    while ($app = $apps_stmt->fetch(PDO::FETCH_ASSOC)):
                        if ($current_category != $app['categoria']):
                            if ($current_category != '') echo "</div>";
                            $current_category = $app['categoria'];
                            echo "<h6 class='mt-3 text-secondary'>" . ucfirst($current_category) . "</h6>";
                            echo "<div class='list-group'>";
                        endif;

                        $iconePath = file_exists('uploads/' . $app['icone']) 
                        ? 'uploads/' . $app['icone'] 
                        : 'uploads/default.png';
                        ?>
                        <div class="list-group-item">
                            <div class="form-check d-flex align-items-center">
                                <input type="checkbox" class="form-check-input app-toggle"
                                data-device="<?= $device['id'] ?>"
                                data-app="<?= $app['id'] ?>"
                                <?= $app['is_enabled'] ? 'checked' : '' ?>>
                                <img src="<?= $iconePath ?>"
                                alt="Ícone de <?= htmlspecialchars($app['nome']) ?>"
                                class="ms-2 me-2"
                                style="width:35px;height:35px;">
                                <label class="form-check-label">
                                    <?= htmlspecialchars($app['nome']) ?>
                                </label>
                            </div>
                        </div>
                        <?php 
                    endwhile;
                    if ($current_category != '') echo "</div>";
                    ?>
                </div>
            </div>
        <?php endforeach; ?>
    <?php endif; ?>
</div>
</div>
</div>

<!-- Modal de Edição -->
<div class="modal fade" id="editModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Editar Dispositivo</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="editForm">
                    <input type="hidden" name="action" value="update">
                    <input type="hidden" name="device_id" id="edit_device_id">
                    <div class="mb-3">
                        <label class="form-label">MAC Address:</label>
                        <input type="text" name="mac_address" id="edit_mac_address" 
                        class="form-control mac-input">
                        <small class="form-text text-muted">
                            Deixe em branco para manter o MAC atual
                        </small>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Nome do Dispositivo:</label>
                        <input type="text" name="device_name" id="edit_device_name" 
                        class="form-control">
                        <small class="form-text text-muted">
                            Deixe em branco para manter o nome atual
                        </small>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                <button type="button" class="btn btn-primary" id="saveEdit">Salvar</button>
            </div>
        </div>
    </div>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.js"></script>

<script>
    $(document).ready(function() {
        // Configuração do Toastr
        toastr.options = {
            "closeButton": true,
            "positionClass": "toast-top-right",
            "preventDuplicates": true,
            "showDuration": "300",
            "hideDuration": "1000",
            "timeOut": "3000",
            "extendedTimeOut": "1000"
        };

        // Formatação de MAC Address
        $('.mac-input').on('input', function() {
            let value = $(this).val().replace(/[^0-9A-Fa-f]/g, '');
            if (value.length > 2) {
                value = value.match(/.{1,2}/g).join(':');
            }
            $(this).val(value.toUpperCase().substring(0, 17));
        });

        // Formulário de adição
        $('#addDeviceForm').on('submit', function(e) {
            e.preventDefault();
            
            const form = $(this);
            const submitButton = form.find('button[type="submit"]');
            
            submitButton.prop('disabled', true);
            
            $.ajax({
                url: window.location.href,
                type: 'POST',
                data: form.serialize(),
                success: function(response) {
                    if (response.success) {
                        toastr.success(response.message);
                        form[0].reset();
                        form.removeClass('was-validated');
                        setTimeout(() => location.reload(), 1000);
                    } else {
                        toastr.error(response.message);
                    }
                },
                error: function() {
                    toastr.error('Erro de conexão com o servidor');
                },
                complete: function() {
                    submitButton.prop('disabled', false);
                }
            });
        });

        // Edição de dispositivo
        $('.edit-device').click(function() {
            const button = $(this);
            const id = button.data('id');
            const name = button.data('name');
            const mac = button.data('mac');
            
            $('#edit_device_id').val(id);
            $('#edit_device_name').val(name);
            $('#edit_mac_address').val(mac);
            
            new bootstrap.Modal(document.getElementById('editModal')).show();
        });

        // Salvar edição
        $('#saveEdit').click(function() {
            const button = $(this);
            const form = $('#editForm');
            
            button.prop('disabled', true);
            
            $.ajax({
                url: window.location.href,
                type: 'POST',
                data: form.serialize(),
                success: function(response) {
                    if (response.success) {
                        const modal = bootstrap.Modal.getInstance(document.getElementById('editModal'));
                        modal.hide();
                        toastr.success(response.message);
                        
                        // Atualiza os dados na tela
                        const deviceId = $('#edit_device_id').val();
                        const newName = $('#edit_device_name').val();
                        const newMac = $('#edit_mac_address').val();
                        const deviceContainer = $(`.edit-device[data-id="${deviceId}"]`).closest('.device-container');
                        
                        if (newName || newMac) {
                            const header = deviceContainer.find('h5.text-primary');
                            const currentMac = header.find('small').text().match(/MAC: (.+)\)/)[1];
                            header.html(`
                                ${newName || header.contents().first().text().trim()}
                                <small class="text-muted">(MAC: ${newMac || currentMac})</small>
                                `);
                        }
                        
                        setTimeout(() => location.reload(), 1000);
                    } else {
                        toastr.error(response.message);
                    }
                },
                error: function() {
                    toastr.error('Erro de conexão com o servidor');
                },
                complete: function() {
                    button.prop('disabled', false);
                }
            });
        });

        // Toggle de status do dispositivo
        $('.device-status-toggle').change(function() {
            const checkbox = $(this);
            const deviceId = checkbox.data('device');
            const status = checkbox.prop('checked') ? 1 : 0;
            const statusLabel = $(`#status-label-${deviceId}`);
            
            $.ajax({
                url: 'toggle_device_status.php',
                type: 'POST',
                data: {
                    device_id: deviceId,
                    status: status
                },
                success: function(response) {
                    if (response.status) {
                // Atualiza o texto e a cor do status
                        statusLabel
                        .text(status ? 'Ativo' : 'Desativado')
                        .removeClass(status ? 'text-danger' : 'text-success')
                        .addClass(status ? 'text-success' : 'text-danger');

                // Mostra mensagem em verde
                        toastr.options = {
                            "positionClass": "toast-top-right",
                            "closeButton": true,
                            "timeOut": "2000",
                            "progressBar": true,
                    "backgroundColor": "#28a745", // cor verde para sucesso
                };
                toastr.success('Status do dispositivo atualizado com sucesso!');

                // Recarrega a página após 2 segundos
                setTimeout(() => {
                    location.reload();
                }, 2000);
            } else {
                // Reverte o checkbox
                checkbox.prop('checked', !status);
                
                // Mostra mensagem em vermelho
                toastr.options = {
                    "closeButton": true,
                    "positionClass": "toast-top-right",
                    "preventDuplicates": true,
                    "onclick": null,
                    "showDuration": "300",
                    "hideDuration": "1000",
                    "timeOut": "2000",
                    "extendedTimeOut": "1000",
                    "showEasing": "swing",
                    "hideEasing": "linear",
                    "showMethod": "fadeIn",
                    "hideMethod": "fadeOut",
                    "progressBar": true
                };
                toastr.error(response.message || 'Erro ao atualizar status');
            }
        },
        error: function() {
            // Reverte o checkbox
            checkbox.prop('checked', !status);
            
            // Mostra mensagem de erro em vermelho
            toastr.options = {
                "positionClass": "toast-top-right",
                "closeButton": true,
                "timeOut": "3000",
                "progressBar": true,
                "backgroundColor": "#dc3545",
            };
            toastr.error('Erro de conexão com o servidor');
        }
    });
        });

        $('.delete-device').click(function() {
            const button = $(this);
            const deviceId = button.data('id');
            const deviceName = button.data('name');
            
            if (confirm(`Deseja realmente excluir o dispositivo "${deviceName}"?`)) {
                $.ajax({
                    url: window.location.href,
                    type: 'POST',
                    data: {
                        action: 'delete',
                        device_id: deviceId
                    },
                    success: function(response) {
                        if (response.success) {
                            toastr.success(response.message);
                            setTimeout(() => location.reload(), 1000);
                        } else {
                            toastr.error(response.message);
                        }
                    },
                    error: function() {
                        toastr.error('Erro de conexão com o servidor');
                    }
                });
            }
        });

        // Toggle de apps
        $('.app-toggle').change(function() {
            const checkbox = $(this);
            const deviceId = checkbox.data('device');
            const appId = checkbox.data('app');
            const status = checkbox.prop('checked') ? 1 : 0;
            
            $.ajax({
                url: 'toggle_app.php',
                type: 'POST',
                data: {
                    device_id: deviceId,
                    app_id: appId,
                    status: status
                },
                success: function(response) {
                    if (response.status) {
                // Configura o toastr para mensagem de sucesso em verde
                        toastr.options = {
                            "closeButton": true,
                            "positionClass": "toast-top-right",
                            "preventDuplicates": true,
                            "timeOut": "2000",
                            "extendedTimeOut": "1000",
                            "progressBar": true,
                            "toastClass": "toast-success",
                    "backgroundColor": "#28a745" // verde
                };
                
                // Mostra mensagem de sucesso em verde
                const message = $('<div>', {
                    class: 'alert alert-success',
                    role: 'alert',
                    style: 'background-color: #28a745; color: white; border: none;'
                }).html('<i class="fas fa-check-circle"></i> Status atualizado com sucesso');

                // Adiciona a mensagem ao topo da página
                $('#messageContainer').html(message);

                // Recarrega a página após 1.5 segundos
                setTimeout(() => {
                    location.reload();
                }, 1500);
            } else {
                // Reverte o checkbox
                checkbox.prop('checked', !status);
                
                // Configura o toastr para mensagem de erro
                toastr.options.toastClass = "toast-error";
                toastr.error(response.message || 'Erro ao atualizar status do app');
            }
        },
        error: function() {
            // Reverte o checkbox
            checkbox.prop('checked', !status);
            toastr.error('Erro de conexão com o servidor');
        }
    });
        });
    });
</script>
</body>
</html>