<?php
session_start();
// Sua lógica de autenticação aqui
require_once 'session_check.php';
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

include_once 'config/database.php';
$database = new Database();
$db = $database->getConnection();
?>

<!DOCTYPE html>
<html lang="pt-BR">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gerenciar Dispositivos</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>

<body>
    <!--- Incluimos o menu navegação --->
    <?php include('nav_bar.php'); ?>

    <div class="container mt-4">
        <!-- Mensagens de erro/sucesso -->
        <?php if (isset($_GET['error'])): ?>
        <div class="alert alert-danger alert-dismissible fade show" role="alert">
            <?php echo htmlspecialchars($_GET['error']); ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
        </div>
        <?php endif; ?>

        <?php if (isset($_GET['success'])): ?>
        <div class="alert alert-success alert-dismissible fade show" role="alert">
            Dispositivo cadastrado com sucesso!
            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
        </div>
        <?php endif; ?>

        <h2>Gerenciar Apps por Dispositivo</h2>

        <!-- Formulário para adicionar novo dispositivo -->
        <div class="card mb-4">
            <div class="card-header">Adicionar Dispositivo</div>
            <div class="card-body">
                <form action="add_device.php" method="POST" class="needs-validation" novalidate>
                    <div class="mb-3">
                        <label>MAC Address:</label>
                        <input type="text" name="mac_address" class="form-control" id="macAddressInput" required
                            pattern="([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})"
                            title="Formato MAC válido: XX:XX:XX:XX:XX:XX" placeholder="00:11:22:33:44:55"
                            maxlength="17">
                        <div class="invalid-feedback">
                            Por favor, insira um MAC válido no formato XX:XX:XX:XX:XX:XX
                        </div>
                    </div>
                    <div class="mb-3">
                        <label>Nome do Dispositivo:</label>
                        <input type="text" name="device_name" class="form-control" required placeholder="Ex: TV Sala">
                        <div class="invalid-feedback">
                            Por favor, insira um nome para o dispositivo
                        </div>
                    </div>
                    <button type="submit" class="btn btn-primary">Adicionar</button>
                </form>
            </div>
        </div>

        <script>
        document.getElementById('macAddressInput').addEventListener('input', function(e) {
            let value = e.target.value.replace(/[^0-9A-Fa-f]/g, ''); // Remove caracteres inválidos
            if (value.length > 2 && value.length % 2 === 0 && value.length < 17) {
                value = value.match(/.{1,2}/g).join(':'); // Adiciona ':' automaticamente a cada dois caracteres
            }
            e.target.value = value.toUpperCase(); // Converte para maiúsculas
        });
        </script>


        <!-- Lista de Dispositivos e Apps -->
        <div class="card">
            <div class="card-header">Dispositivos Cadastrados</div>
            <div class="card-body">
                <?php
                $query = "SELECT * FROM devices ORDER BY device_name";
                $stmt = $db->prepare($query);
                $stmt->execute();

                while ($device = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $deviceChecked = $device['status'] == 1 ? 'checked' : '';
                    echo "<div class='mb-4'>";
                    echo "<h5 style='color: red;'>{$device['device_name']} (MAC: {$device['mac_address']})</h5>";

                    // Checkbox de Ativação/Inativação do Dispositivo
                    echo "<div class='form-check form-switch d-flex align-items-center'>";

                    // Define o texto e a cor do status com base no valor de $deviceChecked
                    $statusText = $device['status'] == 1 ? "Ativo" : "Desativado";
                    $statusColor = $device['status'] == 1 ? "text-success" : "text-danger";

                    echo "<input type='checkbox' class='form-check-input device-status-toggle' 
        data-device='{$device['id']}' {$deviceChecked}>";

                    // Exibe o texto do status com a cor correspondente
                    echo "<label class='form-check-label ms-2 {$statusColor}' id='status-label-{$device['id']}'>
        {$statusText}
      </label>";

                    echo "</div>";

                    // Busca apps
                    $apps_query = "SELECT a.*, 
               CASE WHEN (da.id IS NOT NULL AND da.status = 1) THEN 1 ELSE 0 END as is_enabled 
               FROM apps a 
               LEFT JOIN device_apps da ON da.app_id = a.id 
                  AND da.device_id = :device_id
               WHERE a.status = 1 
               ORDER BY a.categoria, a.ordem, a.nome";
                    $apps_stmt = $db->prepare($apps_query);
                    $apps_stmt->bindParam(":device_id", $device['id']);
                    $apps_stmt->execute();

                    $current_category = '';
                    echo "<div class='list-group mt-3'>";
                    while ($app = $apps_stmt->fetch(PDO::FETCH_ASSOC)) {
                        // Agrupa por categoria
                        if ($current_category != $app['categoria']) {
                            if ($current_category != '') echo "</div>";
                            $current_category = $app['categoria'];
                            echo "<h6 class='mt-3'>{$current_category}</h6>";
                            echo "<div class='list-group'>";
                        }

                        $checked = $app['is_enabled'] ? 'checked' : '';
                        echo "<div class='list-group-item'>";
                        echo "<div class='form-check d-flex align-items-center'>";
                        echo "<input type='checkbox' class='form-check-input app-toggle' data-device='{$device['id']}' data-app='{$app['id']}' {$checked}>" . "&nbsp;&nbsp;";


                        // Define o caminho completo do ícone e verifica se o arquivo existe
                        $iconePath = 'uploads/' . $app['icone'];
                        $iconePath = file_exists($iconePath) ? $iconePath : '../uploads/default.png';

                        echo "<img src='{$iconePath}' alt='Ícone de {$app['nome']}' style='width:35px;height:35px;margin-right:10px;'>";
                        echo "<label class='form-check-label'>{$app['nome']}</label>";
                        echo "</div>";
                        echo "</div>";
                    }
                    echo "</div></div>";
                    echo "</div>";
                }
                ?>

            </div>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
    $(document).ready(function() {
        // Alteração no status do dispositivo
        $('.device-status-toggle').change(function() {
            const deviceId = $(this).data('device');
            const status = $(this).is(':checked') ? 1 : 0;

            // Atualiza o texto e a cor do status no front-end
            const statusLabel = $('#status-label-' + deviceId);
            if (status === 1) {
                statusLabel.text('Ativo').removeClass('text-danger').addClass('text-success');
            } else {
                statusLabel.text('Desativado').removeClass('text-success').addClass('text-danger');
            }

            // Envia a atualização do status para o servidor
            $.post('toggle_device_status.php', {
                device_id: deviceId,
                status: status
            }, function(response) {
                if (response.status) {
                    toastr.success('Status do dispositivo atualizado com sucesso!');
                } else {
                    toastr.error('Erro ao atualizar o status do dispositivo.');
                    // Reverte o checkbox em caso de erro
                    $(this).prop('checked', !status);
                    statusLabel.text(!status ? 'Ativo' : 'Desativado')
                        .toggleClass('text-success text-danger');
                }
            }).fail(function() {
                toastr.error('Erro de conexão');
                $(this).prop('checked', !status);
                statusLabel.text(!status ? 'Ativo' : 'Desativado')
                    .toggleClass('text-success text-danger');
            });
        });

        $('.app-toggle').change(function() {
            const deviceId = $(this).data('device');
            const appId = $(this).data('app');
            const enabled = $(this).is(':checked');
            const status = enabled ? 1 : 0;
            const checkbox = $(this);

            $.post('toggle_app.php', {
                device_id: deviceId,
                app_id: appId,
                status: status
            }, function(response) {
                if (response.status) {
                    toastr.success('App ' + (enabled ? 'ativado' : 'desativado') +
                        ' com sucesso!');
                } else {
                    toastr.error('Erro ao atualizar status do app');
                    checkbox.prop('checked', !enabled); // Reverte o checkbox em caso de erro
                }
            }).fail(function() {
                toastr.error('Erro de conexão');
                checkbox.prop('checked', !enabled); // Reverte o checkbox em caso de erro
            });
        });
    });
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
    // Validação do formulário Bootstrap
    (function() {
        'use strict'
        var forms = document.querySelectorAll('.needs-validation')
        Array.prototype.slice.call(forms)
            .forEach(function(form) {
                form.addEventListener('submit', function(event) {
                    if (!form.checkValidity()) {
                        event.preventDefault()
                        event.stopPropagation()
                    }
                    form.classList.add('was-validated')
                }, false)
            })
    })()
    </script>

</body>

</html>