<?php
session_start();
require_once 'session_check.php';
?>

<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <title>Nova Atualização</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <?php include('nav_bar.php'); ?>

    <div class="container mt-4">
        <h5 style="color: blue; text-align: center;">Adicionar Nova Atualização</h5>

        <?php if (isset($_GET['error'])): ?>
            <div class="alert alert-danger">
                <?php echo htmlspecialchars($_GET['error']); ?>
            </div>
        <?php endif; ?>

        <?php if (isset($_GET['success'])): ?>
            <div class="alert alert-success">
                Atualização cadastrada com sucesso!
            </div>
        <?php endif; ?>

        <div class="card">
            <div class="card-body">
                <form action="add_update.php" method="POST" enctype="multipart/form-data" class="needs-validation" novalidate>
                    <div class="mb-3">
                        <label class="form-label"><b style="color: blue;">Código da Versão:</b></label>
                        <input type="number" name="version_code" class="form-control" required>
                        <div class="form-text" style="color: blue;">Número inteiro que deve aumentar a cada versão (ex: 1, 2, 3)</div>
                    </div>

                    <div class="mb-3">
                        <label class="form-label"><b style="color: blue;">Nome da Versão:</b></label>
                        <input type="text" name="version_name" class="form-control" required 
                               placeholder="Ex: 1.0.0">
                        <div class="form-text" style="color: blue;">Nome amigável da versão (ex: 1.0.0, 1.1.0)</div>
                    </div>

                    <div class="mb-3">
                        <label class="form-label"><b style="color: blue;">Arquivo APK:</b></label>
                        <input type="file" name="apk_file" class="form-control" required 
                               accept=".apk">
                    </div>

                    <div class="mb-3">
                        <label class="form-label"><b style="color: blue;">Changelog:</b></label>
                        <textarea name="changelog" class="form-control" rows="5" required
                                  placeholder="Liste as mudanças desta versão..."></textarea>
                    </div>

                    <div class="mb-3">
                        <div class="form-check">
                            <input type="checkbox" name="force_update" class="form-check-input" id="forceUpdate">
                            <label class="form-check-label" for="forceUpdate">
                                <b style="color: blue;">Atualização Obrigatória</b>
                            </label>
                            <div class="form-text" style="color: blue;">Se marcado, o usuário será obrigado a atualizar</div>
                        </div>
                    </div>

                    <div class="mb-3">
                        <div class="form-check">
                            <input type="checkbox" name="status" class="form-check-input" id="status" checked>
                            <label class="form-check-label" for="status">
                                Ativo
                            </label>
                        </div>
                    </div>

                    <button type="submit" class="btn btn-primary">Adicionar Atualização</button>
                </form>
            </div>
        </div>

        <!-- Lista de atualizações cadastradas -->
        <div class="card mt-4">
            <div class="card-header">
                <h5 style="color: blue; text-align: center;">Atualizações Cadastradas</h5>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>Versão</th>
                            <th>Nome</th>
                            <th>APK</th>
                            <th>Obrigatória</th>
                            <th>Status</th>
                            <th>Data</th>
                            <th>Ações</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        include_once 'config/database.php';
                        $database = new Database();
                        $db = $database->getConnection();

                        $query = "SELECT * FROM launcher_updates ORDER BY version_code DESC";
                        $stmt = $db->prepare($query);
                        $stmt->execute();

                        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                            echo "<tr>";
                            echo "<td>{$row['version_code']}</td>";
                            echo "<td>{$row['version_name']}</td>";
                            echo "<td>{$row['apk_file']}</td>";
                            echo "<td>" . ($row['force_update'] ? 'Sim' : 'Não') . "</td>";
                            echo "<td>" . ($row['status'] ? 'Ativo' : 'Inativo') . "</td>";
                            echo "<td>{$row['created_at']}</td>";
                            echo "<td>";
                            echo "<button class='btn btn-sm btn-danger' onclick='toggleStatus({$row['id']}, {$row['status']})'>".($row['status'] ? 'Desativar' : 'Ativar')."</button>";
                            echo "</td>";
                            echo "</tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>
            </div>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    
    <script>
    function toggleStatus(id, currentStatus) {
        if (confirm('Deseja alterar o status desta atualização?')) {
            $.post('toggle_update_status.php', {
                id: id,
                status: currentStatus ? 0 : 1
            }, function(response) {
                if (response.status) {
                    location.reload();
                } else {
                    alert('Erro ao alterar status');
                }
            });
        }
    }

    // Validação do formulário
    (function () {
        'use strict'
        var forms = document.querySelectorAll('.needs-validation')
        Array.prototype.slice.call(forms)
            .forEach(function (form) {
                form.addEventListener('submit', function (event) {
                    if (!form.checkValidity()) {
                        event.preventDefault()
                        event.stopPropagation()
                    }
                    form.classList.add('was-validated')
                }, false)
            })
    })()
    </script>
</body>
</html>