<?php
require_once 'session_check.php';
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'config.php';

$configManager = new ConfigManager($pdo);
$appsManager = new AppsManager($pdo);

$dominioSalvo = ''; // Inicializa a variável para exibir o domínio salvo

// Processamento do formulário para salvar o domínio
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $dominio = trim($_POST['dominio'] ?? '');

    if (!empty($dominio)) {
        try {
            // Insere ou atualiza o domínio no banco de dados
            $stmt = $pdo->prepare("INSERT INTO configuracoes_dominio (id, dominio) VALUES (1, ?) 
             ON DUPLICATE KEY UPDATE dominio = VALUES(dominio)");
            $stmt->execute([$dominio]);

            // Redireciona para evitar o reenvio do formulário
            header('Location: index.php');
            exit;
        } catch (Exception $e) {
            header('Location: index.php?error=' . urlencode($e->getMessage()));
            exit;
        }
    }
}

// Carrega o domínio salvo no banco de dados, se existir
$stmt = $pdo->query("SELECT dominio FROM configuracoes_dominio WHERE id = 1");
$dominioSalvo = $stmt->fetchColumn();


if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';

    switch ($action) {
        case 'add':
            // Adiciona um novo app
            try {
                $nome = $_POST['nome'] ?? '';
                $pacote = $_POST['pacote'] ?? '';
                $categoria = $_POST['categoria'] ?? 'utilidades';
                $ordem = $_POST['ordem'] ?? 0;
                $apk_url = $_POST['apk_url'] ?? '';

                // Define o nome do ícone com base no nome do app
                $icone = '';
                if (isset($_FILES['icone']) && $_FILES['icone']['error'] === 0) {
                    $iconeFileName = strtolower(str_replace(' ', '_', $nome)) . '.png';
                    $iconePath = 'uploads/' . $iconeFileName;

                    // Move o arquivo enviado para o caminho com o nome especificado
                    if (move_uploaded_file($_FILES['icone']['tmp_name'], $iconePath)) {
                        $icone = $iconeFileName;
                    } else {
                        throw new Exception("Erro ao mover o arquivo de ícone.");
                    }
                }

                // Salva o novo app no banco de dados com o nome do ícone atualizado
                $appsManager->addApp($nome, $pacote, $categoria, $ordem, $icone, $apk_url);
                header('Location: index.php?success=add');
                exit;
            } catch (Exception $e) {
                header('Location: index.php?error=' . urlencode($e->getMessage()));
                exit;
            }
            break;

        case 'update':
            try {
                // Valida e obtém os dados
                $id = filter_input(INPUT_POST, 'id', FILTER_VALIDATE_INT);
                if (!$id) {
                    throw new Exception("ID inválido");
                }

                $nome = filter_input(INPUT_POST, 'nome', FILTER_SANITIZE_STRING);
                $pacote = filter_input(INPUT_POST, 'pacote', FILTER_SANITIZE_STRING);
                $categoria = filter_input(INPUT_POST, 'categoria', FILTER_SANITIZE_STRING);
                $ordem = filter_input(INPUT_POST, 'ordem', FILTER_VALIDATE_INT);

                // Processa o ícone apenas se um novo for enviado
                $icone = null;
                if (isset($_FILES['icone']) && $_FILES['icone']['error'] === 0) {
                    // Gera nome único para o ícone baseado no nome do app e timestamp
                    $iconeFileName = strtolower(str_replace(' ', '_', $nome)) . '_' . time() . '.png';
                    $iconePath = 'uploads/' . $iconeFileName;

                    if (move_uploaded_file($_FILES['icone']['tmp_name'], $iconePath)) {
                        $icone = $iconeFileName;

                        // Opcional: remove o ícone antigo
                        $oldIcon = $appsManager->getAppIcon($id);
                        if ($oldIcon && file_exists('uploads/' . $oldIcon)) {
                            unlink('uploads/' . $oldIcon);
                        }
                    } else {
                        throw new Exception("Erro ao fazer upload do ícone");
                    }
                }

                // Atualiza o app
                if ($appsManager->updateApp($id, $nome, $pacote, $categoria, $ordem, $icone)) {
                    $_SESSION['success'] = "App atualizado com sucesso!";
                    header('Location: index.php');
                } else {
                    throw new Exception("Falha ao atualizar o app");
                }
            } catch (Exception $e) {
                $_SESSION['error'] = $e->getMessage();
                header('Location: index.php?error=' . urlencode($e->getMessage()));
            }
            exit;
            break;



        case 'delete':
            // Exclui um app existente
            $id = $_POST['id'] ?? null;
            if ($id) {
                if (!is_numeric($id)) {
                    header('Location: index.php?error=invalid_id_format');
                    exit;
                }

                // Tente excluir e verifique se a exclusão foi bem-sucedida
                if ($appsManager->deleteApp($id)) {
                    header('Location: index.php?success=delete');
                } else {
                    header('Location: index.php?error=delete_failed');
                }
                exit;
            } else {
                header('Location: index.php?error=missing_id');
                exit;
            }
            break;
    }
}
?>
<!DOCTYPE html>
<html lang="pt-BR">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Painel Administrativo - TV Box Launcher</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .progress {
            width: 100%;
            height: 30px;
            background: #f0f0f0;
            margin: 15px 0;
            border-radius: 4px;
        }

        .progress-bar {
            width: 0%;
            height: 100%;
            background: #4CAF50;
            text-align: center;
            line-height: 30px;
            color: white;
            border-radius: 4px;
            transition: width 0.3s ease;
        }

        #status {
            margin-top: 10px;
            padding: 10px;
            border-radius: 4px;
        }

        .success {
            background: #dff0d8;
            color: #3c763d;
        }

        .error {
            background: #f2dede;
            color: #a94442;
        }

        /* Adicione estes estilos */
        .uploaded-files {
            margin-top: 30px;
        }

        .btn-download,
        .btn-delete {
            padding: 5px 10px;
            border-radius: 3px;
            text-decoration: none;
            margin: 0 5px;
            display: inline-block;
        }

        .btn-download {
            background: #4CAF50;
            color: white;
        }

        .btn-delete {
            background: #f44336;
            color: white;
        }

        table {
            border-collapse: collapse;
            width: 100%;
        }

        th,
        td {
            padding: 8px;
            text-align: left;
            border: 1px solid #ddd;
        }

        th {
            background-color: #f5f5f5;
        }

        tr:nth-child(even) {
            background-color: #f9f9f9;
        }
    </style>
</head>

<body>
    <!--- Incluimos o menu navegação --->
    <?php include('nav_bar.php'); ?>

    <div class="container mt-4">
        <div class="card mb-4">
            <div class="card-header">
                <h5 style="text-align: center; color: blue;">Configuração de Domínio</h5>
            </div>

            <?php if (isset($_GET['success'])): ?>
                <div class="alert alert-success">Domínio salvo com sucesso!</div>
            <?php endif; ?>

            <?php if (isset($_GET['error'])): ?>
                <div class="alert alert-danger">Erro: <?= htmlspecialchars($_GET['error']) ?></div>
            <?php endif; ?>

            <div class="container">

                <form method="POST">
                    <div class="mb-3">
                        <label for="dominio" class="form-label"><b style="color: blue;">Domínio</b></label>
                        <input type="text" name="dominio" id="dominio" class="form-control"
                            placeholder="Digite seu dominio.. https://dominio Ou http://dominio" required>
                    </div>
                    <button type="submit" class="btn btn-primary">Salvar</button>
                    <?php if ($dominioSalvo): ?>
                        <div class="mt-4">
                            <h5 style="color:blue;">Domínio Atual:</h5>
                            <p><?= htmlspecialchars($dominioSalvo) ?></p>
                        </div>
                    <?php endif; ?>
                </form>
            </div>
        </div>
    </div>

    <div class="container mt-4">

        <?php if (isset($_GET['success'])): ?>
            <div class="alert alert-success alert-dismissible fade show" role="alert">
                Operação realizada com sucesso!
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <?php if (isset($_GET['error'])): ?>
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                Erro: <?= htmlspecialchars($_GET['error']) ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <!-- Formulário de Adicionar -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title mb-0" style="text-align: center; color: blue;">Adicionar novo App no servidor</h5>
            </div>
            <div class="container mt-4">
                <small class="form-text text-muted">Selecione seu apk para upload.</small><br>
                <form id="uploadForm" method="post" enctype="multipart/form-data">
                    <input type="file" name="apk_file" accept=".apk" required>
                    <button type="button" class="btn btn-primary" onclick="uploadAPK()">Upload</button>
                </form>

                <div class="progress">
                    <div id="progressBar" class="progress-bar">0%</div>
                </div>
                <div id="status"></div>

                <div class="uploaded-files">
                    <div class="card-header">
                        <h5 style="text-align: center; color: blue;">APKs Disponíveis</h5>
                    </div>
                    <div class="table-responsive">
                        <table border="1" style="width: 100%; white-space: nowrap;">
                            <thead>
                                <tr>
                                    <th>Nome</th>
                                    <th>Tamanho</th>
                                    <th>Data Upload</th>
                                    <th>Ações</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                $apks_dir = 'apks/';
                                if (is_dir($apks_dir)) {
                                    $files = glob($apks_dir . '*.apk');
                                    foreach ($files as $file) {
                                        $name = basename($file);
                                        $size = round(filesize($file) / (1024 * 1024), 2); // Tamanho em MB
                                        $date = date("d/m/Y H:i:s", filemtime($file));
                                        echo "<tr>";
                                        echo "<td>$name</td>";
                                        echo "<td>{$size}MB</td>";
                                        echo "<td>$date</td>";
                                        echo "<td>
                    <a href='$file' class='btn-download'>Download</a>
                    <a href='#' onclick='deleteApk(\"$name\")' class='btn-delete'>Excluir</a>
                    </td>";
                                        echo "</tr>";
                                    }
                                }
                                ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <hr>


            <div class="card-body">

                <div class="card-header">
                    <h5 style="color: blue; text-align: center;">Cadastrar apps</h5>
                </div>
                <form action="" method="POST" enctype="multipart/form-data" id="addForm">
                    <input type="hidden" name="action" value="add">
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label class="form-label"><b style="color: blue;">Nome do App</b></label>
                            <input type="text" name="nome" class="form-control">
                        </div>
                        <div class="col-md-6 mb-3">
                            <label class="form-label"><b style="color: blue;">Package Name</b></label>
                            <input type="text" name="pacote" class="form-control">
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-4 mb-3">
                            <label class="form-label"><b style="color: blue;">Categoria</b></label>
                            <select name="categoria" class="form-select">
                                <option value="jogos"><b style="color: blue;">Jogos</b></option>
                                <option value="midia"><b style="color: blue;">Mídia</b></option>
                                <option value="utilidades"><b style="color: blue;">Utilidades</b></option>
                            </select>
                        </div>
                        <div class="col-md-4 mb-3">
                            <label class="form-label"><b style="color: blue;">Ordem</b></label>
                            <input type="number" name="ordem" class="form-control" value="0">
                            <small class="form-text text-muted">Ordem que seu app vai ser mostrado na launcher.</small>
                        </div>
                        <div class="col-md-4 mb-3">
                            <label class="form-label"><b style="color: blue;">Ícone</b></label>
                            <input type="file" name="icone" class="form-control">
                            <small class="form-text text-muted">Recomendado: imagem de 200x200 pixels.</small>
                        </div>

                        <div class="col-md-6 mb-3">
                            <label class="form-label"><b style="color: blue;">Url apk</b></label>

                            <?php if ($dominioSalvo): ?>

                                <input type="text" name="apk_url" class="form-control"
                                    value="<?= htmlspecialchars($dominioSalvo) ?>/launcher/apks/">
                            <?php endif; ?>

                            <small class="form-text text-muted">Complete a url depois de /apks com o nome do seu apk de
                                cadastro.</small>
                        </div>


                    </div>
                    <button type="submit" class="btn btn-primary">Salvar</button>
                </form>
            </div>
        </div>

        <!-- Lista de Apps -->
        <div class="card">
            <div class="card-header">
                <h5 class="card-title mb-0" style="text-align: center; color: blue;">Apps Cadastrados</h5>
            </div>
            <div class="card-body">
                <div class="table-responsive" style="white-space: nowrap;">
                    <table class="table">
                        <thead>
                            <tr>
                                <th><b style="color: blue;">Ordem</b></th>
                                <th><b style="color: blue;">Ícone</b></th>
                                <th><b style="color: blue;">Nome</b></th>
                                <th><b style="color: blue;">Package</b></th>
                                <th><b style="color: blue;">Url apk</b></th>
                                <th><b style="color: blue;">Categoria</b></th>
                                <th><b style="color: blue;">Ações</b></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            require_once 'config.php';
                            $appsManager = new AppsManager($pdo);
                            $apps = $appsManager->getApps();

                            foreach ($apps as $app):
                                // Define o caminho completo do ícone
                                $iconePath = 'uploads/' . $app['icone'];
                            ?>
                                <tr>
                                    <td><?= $app['ordem'] ?></td>
                                    <td>
                                        <?php if (!empty($app['icone']) && file_exists($iconePath)): ?>
                                            <img src="<?= $iconePath ?>" alt="<?= htmlspecialchars($app['nome']) ?>"
                                                style="width: 40px; height: 40px;">
                                        <?php else: ?>
                                            <img src="uploads/default.png" alt="Ícone Padrão"
                                                style="width: 40px; height: 40px;">
                                        <?php endif; ?>
                                    </td>
                                    <td><?= htmlspecialchars($app['nome']) ?></td>
                                    <td><?= htmlspecialchars($app['pacote']) ?></td>
                                    <td><?= htmlspecialchars($app['apk_url']) ?></td>
                                    <td><?= ucfirst(htmlspecialchars($app['categoria'])) ?></td>
                                    <td>
                                        <button class="btn btn-sm btn-primary edit-app" data-id="<?= $app['id'] ?>"
                                            data-nome="<?= htmlspecialchars($app['nome']) ?>"
                                            data-pacote="<?= htmlspecialchars($app['pacote']) ?>"
                                            data-categoria="<?= htmlspecialchars($app['categoria']) ?>"
                                            data-ordem="<?= $app['ordem'] ?>">
                                            Editar
                                        </button>
                                        <button class="btn btn-sm btn-danger delete-app"
                                            data-id="<?= htmlspecialchars($app['id']) ?>">
                                            Excluir
                                        </button>

                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>

                    </table>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal de Edição -->
    <div class="modal fade" id="editModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Editar App</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <form action="" method="POST" enctype="multipart/form-data" id="editForm">
                        <input type="hidden" name="action" value="update"> <!-- Mudou de "edit" para "update" -->
                        <input type="hidden" name="id" id="edit_id">
                        <div class="mb-3">
                            <label class="form-label">Nome do App</label>
                            <input type="text" name="nome" id="edit_nome" class="form-control" required>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Package Name</label>
                            <input type="text" name="pacote" id="edit_pacote" class="form-control" required>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Categoria</label>
                            <select name="categoria" id="edit_categoria" class="form-select">
                                <option value="jogos">Jogos</option>
                                <option value="midia">Mídia</option>
                                <option value="utilidades">Utilidades</option>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Ordem</label>
                            <input type="number" name="ordem" id="edit_ordem" class="form-control">
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Novo Ícone (opcional)</label>
                            <input type="file" name="icone" class="form-control">
                        </div>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                    <button type="button" class="btn btn-primary" id="saveEdit">Salvar</button>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal de Confirmação de Exclusão -->
    <div class="modal fade" id="deleteModal" tabindex="-1" aria-labelledby="deleteModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteModalLabel">Confirmar Exclusão</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    Tem certeza de que deseja excluir este app?
                </div>
                <div class="modal-footer">
                    <form action="index.php" method="POST" id="deleteForm">
                        <input type="hidden" name="action" value="delete">
                        <input type="hidden" name="id" id="delete_id">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                        <button type="submit" class="btn btn-danger">Confirmar Exclusão</button>
                    </form>
                </div>
            </div>
        </div>
    </div>


    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function uploadAPK() {
            const form = document.getElementById('uploadForm');
            const fileInput = form.querySelector('input[type="file"]');
            const progressBar = document.getElementById('progressBar');
            const status = document.getElementById('status');

            // Resetar status
            status.className = '';
            status.textContent = '';
            progressBar.style.width = '0%';
            progressBar.textContent = '0%';

            // Verificar arquivo
            if (!fileInput.files.length) {
                status.className = 'error';
                status.textContent = 'Selecione um arquivo APK';
                return;
            }

            const file = fileInput.files[0];

            // Verificar extensão
            if (!file.name.toLowerCase().endsWith('.apk')) {
                status.className = 'error';
                status.textContent = 'Arquivo deve ser um APK';
                return;
            }

            const formData = new FormData(form);

            const xhr = new XMLHttpRequest();
            xhr.open('POST', 'processapk.php', true);

            // Progresso do upload
            xhr.upload.onprogress = function(e) {
                if (e.lengthComputable) {
                    const percent = (e.loaded / e.total) * 100;
                    progressBar.style.width = percent + '%';
                    progressBar.textContent = Math.round(percent) + '%';
                }
            };

            // Resposta do servidor
            xhr.onload = function() {
                try {
                    const response = JSON.parse(xhr.responseText);
                    status.className = response.success ? 'success' : 'error';
                    status.textContent = response.message;

                    if (response.success) {
                        form.reset();
                        progressBar.style.width = '100%';
                        progressBar.textContent = 'Completo!';
                        // Recarrega a página para atualizar a lista
                        setTimeout(() => location.reload(), 1000);
                    }
                } catch (e) {
                    status.className = 'error';
                    status.textContent = 'Erro ao processar resposta do servidor';
                }
            };

            xhr.send(formData);
        }

        // Adicione esta função para deletar APKs
        function deleteApk(filename) {
            if (confirm('Tem certeza que deseja excluir este APK?')) {
                fetch('delete_apk.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/x-www-form-urlencoded',
                        },
                        body: 'filename=' + encodeURIComponent(filename)
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (data.success) {
                            location.reload();
                        } else {
                            alert('Erro ao excluir: ' + data.message);
                        }
                    })
                    .catch(error => {
                        console.error('Erro:', error);
                        alert('Erro ao excluir o arquivo');
                    });
            }
        }

        // Atualiza a lista após upload bem-sucedido
        function onUploadSuccess() {
            location.reload();
        }
    </script>
    <script>
        document.getElementById('saveEdit').addEventListener('click', function() {
            const form = document.getElementById('editForm');
            const nome = document.getElementById('edit_nome').value.trim();
            const pacote = document.getElementById('edit_pacote').value.trim();

            if (!nome) {
                alert('Por favor, preencha o nome do app');
                return;
            }
            if (!pacote) {
                alert('Por favor, preencha o package name');
                return;
            }

            form.submit();
        });
        // Modal de edição
        const editModal = new bootstrap.Modal(document.getElementById('editModal'));

        // Botões de edição
        document.querySelectorAll('.edit-app').forEach(button => {
            button.addEventListener('click', function() {
                const data = this.dataset;
                document.getElementById('edit_id').value = data.id;
                document.getElementById('edit_nome').value = data.nome;
                document.getElementById('edit_pacote').value = data.pacote;
                document.getElementById('edit_categoria').value = data.categoria;
                document.getElementById('edit_ordem').value = data.ordem;
                editModal.show();
            });
        });

        // Salvar edição
        document.getElementById('saveEdit').addEventListener('click', function() {
            document.getElementById('editForm').submit();
        });

        // Lógica para abrir o modal de exclusão com o ID do item selecionado
        document.querySelectorAll('.delete-app').forEach(button => {
            button.addEventListener('click', function() {
                const id = this.dataset.id; // Obtém o ID do app a partir do atributo data-id
                document.getElementById('delete_id').value = id; // Define o ID no campo oculto do modal

                // Abre o modal de exclusão
                var deleteModal = new bootstrap.Modal(document.getElementById('deleteModal'));
                deleteModal.show();
            });
        });
    </script>

</body>

</html>