<?php
// Habilita exibição de erros
ini_set('display_errors', 1);
error_reporting(E_ALL);

// Log para debug
error_log("Iniciando processamento do upload");
error_log("FILES: " . print_r($_FILES, true));

// Headers
header('Content-Type: application/json');

try {
    // Verifica se recebeu o arquivo
    if (!isset($_FILES['apk_file'])) {
        throw new Exception("Nenhum arquivo enviado");
    }

    $file = $_FILES['apk_file'];
    error_log("Arquivo recebido: " . print_r($file, true));

    // Verifica erros no upload
    if ($file['error'] !== UPLOAD_ERR_OK) {
        throw new Exception("Erro no upload: " . $file['error']);
    }

    // Verifica tamanho (opcional)
    $maxSize = 200 * 1024 * 1024; // 200MB
    if ($file['size'] > $maxSize) {
        throw new Exception("Arquivo muito grande. Máximo: 200MB");
    }

    // Verifica extensão
    $ext = strtolower(pathinfo($file['name'], PATHINFO_EXTENSION));
    if ($ext !== 'apk') {
        throw new Exception("Arquivo deve ser um APK válido");
    }

    // Cria diretório se não existir
    if (!is_dir('updates')) {
        if (!mkdir('updates', 0777, true)) {
            throw new Exception("Não foi possível criar o diretório de uploads");
        }
        chmod('updates', 0777);
    }

    // Nome único para o arquivo
    $fileName = preg_replace('/[^a-zA-Z0-9\.]/', '_', $file['name']);
    $filePath = 'updates/' . $fileName;

    error_log("Tentando mover para: " . $filePath);

    // Move o arquivo
    if (!move_uploaded_file($file['tmp_name'], $filePath)) {
        throw new Exception("Falha ao mover o arquivo. Verifique as permissões.");
    }

    chmod($filePath, 0644);

    // Sucesso
    echo json_encode([
        'success' => true,
        'message' => 'Upload realizado com sucesso!',
        'file' => $filePath
    ]);

} catch (Exception $e) {
    error_log("Erro: " . $e->getMessage());
    echo json_encode([
        'success' => false,
        'message' => $e->getMessage()
    ]);
}