<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");

session_start();

// Verifique se o usurio est autenticado
require_once 'session_check.php';
include_once 'config/database.php';

try {
    $database = new Database();
    $db = $database->getConnection();

    // Verifique se os parmetros necessrios foram enviados
    if (!isset($_POST['device_id']) || !isset($_POST['status'])) {
        echo json_encode([
            "status" => false,
            "message" => "Parmetros invlidos."
        ]);
        exit;
    }

    $device_id = intval($_POST['device_id']);
    $status = intval($_POST['status']) === 1 ? 1 : 0; // Apenas aceita 0 ou 1

    // Atualize o status do dispositivo
    $query = "UPDATE devices SET status = :status WHERE id = :device_id";
    $stmt = $db->prepare($query);
    $stmt->bindParam(':status', $status, PDO::PARAM_INT);
    $stmt->bindParam(':device_id', $device_id, PDO::PARAM_INT);

    if ($stmt->execute()) {
        echo json_encode([
            "status" => true,
            "message" => "Status do dispositivo atualizado com sucesso."
        ]);
    } else {
        echo json_encode([
            "status" => false,
            "message" => "Erro ao atualizar o status do dispositivo."
        ]);
    }
} catch (PDOException $e) {
    echo json_encode([
        "status" => false,
        "message" => "Erro no banco de dados: " . $e->getMessage()
    ]);
}
?>
