<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);
?>
<!DOCTYPE html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8">
    <title>Upload APK</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            padding: 20px;
        }
        .progress {
            width: 100%;
            height: 30px;
            background: #f0f0f0;
            margin: 15px 0;
            border-radius: 4px;
        }
        .progress-bar {
            width: 0%;
            height: 100%;
            background: #4CAF50;
            text-align: center;
            line-height: 30px;
            color: white;
            border-radius: 4px;
            transition: width 0.3s ease;
        }
        #status {
            margin-top: 10px;
            padding: 10px;
            border-radius: 4px;
        }
        .success { background: #dff0d8; color: #3c763d; }
        .error { background: #f2dede; color: #a94442; }
    </style>
</head>
<body>
    <h2>Upload de APK</h2>
    <form id="uploadForm" method="post" enctype="multipart/form-data">
        <input type="file" name="apk_file" accept=".apk" required>
        <button type="button" onclick="uploadAPK()">Upload</button>
    </form>

    <div class="progress">
        <div id="progressBar" class="progress-bar">0%</div>
    </div>
    <div id="status"></div>

<div class="uploaded-files">
    <h3>APKs Disponíveis</h3>
    <table border="1" style="width: 100%; margin-top: 20px;">
        <thead>
            <tr>
                <th>Nome</th>
                <th>Tamanho</th>
                <th>Data Upload</th>
                <th>Ações</th>
            </tr>
        </thead>
        <tbody>
            <?php
            $apks_dir = 'apks/';
            if (is_dir($apks_dir)) {
                $files = glob($apks_dir . '*.apk');
                foreach ($files as $file) {
                    $name = basename($file);
                    $size = round(filesize($file) / (1024*1024), 2); // Tamanho em MB
                    $date = date("d/m/Y H:i:s", filemtime($file));
                    echo "<tr>";
                    echo "<td>$name</td>";
                    echo "<td>{$size}MB</td>";
                    echo "<td>$date</td>";
                    echo "<td>
                            <a href='$file' class='btn-download'>Download</a>
                            <a href='#' onclick='deleteApk(\"$name\")' class='btn-delete'>Excluir</a>
                         </td>";
                    echo "</tr>";
                }
            }
            ?>
        </tbody>
    </table>
</div>

<style>
/* Adicione estes estilos */
.uploaded-files {
    margin-top: 30px;
}
.btn-download, .btn-delete {
    padding: 5px 10px;
    border-radius: 3px;
    text-decoration: none;
    margin: 0 5px;
    display: inline-block;
}
.btn-download {
    background: #4CAF50;
    color: white;
}
.btn-delete {
    background: #f44336;
    color: white;
}
table {
    border-collapse: collapse;
    width: 100%;
}
th, td {
    padding: 8px;
    text-align: left;
    border: 1px solid #ddd;
}
th {
    background-color: #f5f5f5;
}
tr:nth-child(even) {
    background-color: #f9f9f9;
}
</style>

<script>
// Adicione esta função para deletar APKs
function deleteApk(filename) {
    if (confirm('Tem certeza que deseja excluir este APK?')) {
        fetch('delete_apk.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: 'filename=' + encodeURIComponent(filename)
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                location.reload();
            } else {
                alert('Erro ao excluir: ' + data.message);
            }
        })
        .catch(error => {
            console.error('Erro:', error);
            alert('Erro ao excluir o arquivo');
        });
    }
}

// Atualiza a lista após upload bem-sucedido
function onUploadSuccess() {
    location.reload();
}
</script>

    <script>
        function uploadAPK() {
            const form = document.getElementById('uploadForm');
            const fileInput = form.querySelector('input[type="file"]');
            const progressBar = document.getElementById('progressBar');
            const status = document.getElementById('status');

            // Resetar status
            status.className = '';
            status.textContent = '';
            progressBar.style.width = '0%';
            progressBar.textContent = '0%';

            // Verificar arquivo
            if (!fileInput.files.length) {
                status.className = 'error';
                status.textContent = 'Selecione um arquivo APK';
                return;
            }

            const file = fileInput.files[0];
            
            // Verificar extensão
            if (!file.name.toLowerCase().endsWith('.apk')) {
                status.className = 'error';
                status.textContent = 'Arquivo deve ser um APK';
                return;
            }

            const formData = new FormData(form);

            const xhr = new XMLHttpRequest();
            xhr.open('POST', 'processapk.php', true);

            // Progresso do upload
            xhr.upload.onprogress = function(e) {
                if (e.lengthComputable) {
                    const percent = (e.loaded / e.total) * 100;
                    progressBar.style.width = percent + '%';
                    progressBar.textContent = Math.round(percent) + '%';
                }
            };

            // Resposta do servidor
            xhr.onload = function() {
        try {
            const response = JSON.parse(xhr.responseText);
            status.className = response.success ? 'success' : 'error';
            status.textContent = response.message;
            
            if (response.success) {
                form.reset();
                progressBar.style.width = '100%';
                progressBar.textContent = 'Completo!';
                // Recarrega a página para atualizar a lista
                setTimeout(() => location.reload(), 1000);
            }
        } catch (e) {
            status.className = 'error';
            status.textContent = 'Erro ao processar resposta do servidor';
        }
    };

            xhr.send(formData);
        }
    </script>
</body>
</html>